% Nodes and weights of the Gauss-Hermite quadrature formula 
function [x,w] = gauss_hermite_quadrature(M,gamma)
ab(:,1) = zeros(M,1); 
ab(:,2) = [sqrt(pi);1/2*[1:M-1]'];
J = zeros(M);
for m = 1:M 
    J(m,m) = ab(m,1); 
end
for m = 2:M
    J(m,m-1) = sqrt(ab(m,2));
    J(m-1,m) = J(m,m-1);
end
[V,D] = eig(J);
[D,I] = sort(diag(D));
V = V(:,I);
xw = [D ab(1,2)*V(1,:)'.^2];
% Symmetrisation
xw(:,1) = (xw(:,1)-flipud(xw(:,1)))/2;
xw(:,2) = (xw(:,2)+flipud(xw(:,2)))/2;
x = xw(:,1)/gamma;
w = xw(:,2)/gamma;
[dummy,idx] = sort(abs(x),'descend');
x = x(idx);
w = w(idx);